@@ -3,8 +3,11 @@ from .sources import (
     DotEnvSettingsSource,
     EnvSettingsSource,
     InitSettingsSource,
+    JsonConfigSettingsSource,
     PydanticBaseSettingsSource,
     SecretsSettingsSource,
+    TomlConfigSettingsSource,
+    YamlConfigSettingsSource,
 )
 from .version import VERSION
 
@@ -13,9 +16,12 @@ __all__ = (
     'DotEnvSettingsSource',
     'EnvSettingsSource',
     'InitSettingsSource',
+    'JsonConfigSettingsSource',
     'PydanticBaseSettingsSource',
     'SecretsSettingsSource',
     'SettingsConfigDict',
+    'TomlConfigSettingsSource',
+    'YamlConfigSettingsSource',
     '__version__',
 )
 
